#!/bin/sh
# -*- tcl -*-
# The next line is executed by /bin/sh, but not tcl \
exec tclsh "$0" ${1+"$@"}

package require sqlite3

sqlite3 db WsExample.db

##
## Create the tables for elements
##
db eval {create table element (symbol text, elementNumber int, elementName text)}
db eval {create table isotope (symbol text, counter int, weight real)}

##
## Create the tables for compounds
##
db eval {create table compound (compoundName text, freezesAt real, boilsAt real)}
db eval {create table components (compoundName text, symbol text, counter int, count int)}
db eval {create table specificHeat (compoundName text, phase text, heatContent real)}

#db eval {commit}

##
## Load up the elements
##
set ifd [open Elements.txt r]
set inHeader 1
set counter 0
array set pos {
    number,start 0
    number,end 2
    symbol,start 4
    symbol,end 6
    weight,start 13
    weight,end 31
}
while {[gets $ifd line] != -1} {
    if {[string match {_*} $line]} {
        set inHeader 0
        set element {}
        set counter 0
    } elseif {!$inHeader && !$counter} {
        ##
        ## First line of an element
        ##
        scan [string trim [string range $line $pos(weight,start) $pos(weight,end)]] {%f} weight
        set number [string trim [string range $line $pos(number,start) $pos(number,end)]]
        set symbol [string trim [string range $line $pos(symbol,start) $pos(symbol,end)]]
        incr counter
        db eval {insert into element (symbol, elementNumber, elementName) values ($symbol, $number, $symbol)}
        db eval {insert into isotope (symbol, counter, weight) values ($symbol, $counter, $weight)}
    } elseif {!$inHeader} {
        ##
        ## An isotope line
        ##
        scan [string trim [string range $line $pos(weight,start) $pos(weight,end)]] {%f} weight
        incr counter
        db eval {insert into isotope (symbol, counter, weight) values ($symbol, $counter, $weight)}
    }
}
close $ifd

##
## Close the DB and exit
##
#db eval {commit}
db close
exit 0
